@@ -121,12 +121,34 @@ class AnilistManager():
 
             session_item.episodesInTotal = episodesInTotal or session_item.episodesInTotal or session_item.availableEpisodes
 
+
+        watch_list = self.get_watching()
+
+        new_items:List[SessionItem] = []
+
+        for item in session.session_items:
+            if item.status != 'complete' or not item.anilist_id:
+                new_items.append(item)
+
+
+        for watch_item in watch_list:
+            found_item = session.find(watch_item.anime, anilist_id=watch_item.anilist_id)
+
+            if found_item:
+                found_item.anilist_id = watch_item.anilist_id
+                found_item.episodesInTotal = watch_item.episodesInTotal
+                if found_item in new_items:
+                    new_items.remove(found_item)
+
+        if not new_items:
+            return
+
         pbar = None
         if verbose:
             pbar = ProgressBar(total=len(session.session_items), postfix='Sincronizando com Anilist', leave=False)
 
         with ThreadPoolExecutor(max_workers=4) as executor:
-            futures = [executor.submit(updateSessionItem, session_item) for session_item in session.session_items]
+            futures = [executor.submit(updateSessionItem, session_item) for session_item in new_items]
             for _ in as_completed(futures):
                 if pbar:
                     pbar.update(1)
@@ -159,10 +181,16 @@ class AnilistManager():
         }
         '''
         result = self._request(query, variables)
-        result = result['data']['Page']['mediaList']
-
         watch_list: List[SessionItem] = []
 
+        try:
+            result = result['data']['Page']['mediaList']
+        except KeyError:
+            return watch_list
+        except TypeError:
+            return watch_list
+
+
 
         for item in result:
             media = item['media']
@@ -174,7 +202,8 @@ class AnilistManager():
                     item['progress'] or 1,
                     '',
                     anilist_id=media['id'],
-                    duration=media['duration']*60
+                    duration=media['duration']*60,
+                    watchTime=media['duration']*60
                 )
             )
 
@@ -224,6 +253,7 @@ class AnilistManager():
             if session.has_anime(watch_item.anime, anilist_id=watch_item.anilist_id):
                 intersecting_items.append(watch_item)
             else:
+                session.add_session_items([watch_item])
                 new_items.append(watch_item)
 
         if preferRemote:
@@ -231,7 +261,7 @@ class AnilistManager():
                 session.update(watch_item.anime, watch_item.lastEpisode, watch_item.watchTime, watch_item.duration, episodesInTotal=watch_item.episodesInTotal)
         else:
             for watch_item in intersecting_items:
-                session.update(watch_item.anime, episodesInTotal=watch_item.episodesInTotal)
+                session.update(watch_item.anime, episodesInTotal=watch_item.episodesInTotal, anilist_id=watch_item.anilist_id)
 
 
         session.add_session_items(new_items, inplace=True)
